Auxiliary algorithms and data structures
==========================================

Algorithms
----------

.. autoapifunction:: routingblocks.utility.sample_positions

InsertionCache
--------------

.. autoapiclass:: routingblocks.InsertionMove
    :members:
    :undoc-members:

.. autoapiclass:: routingblocks.InsertionCache
    :members:
    :undoc-members:

RemovalCache
------------

.. autoapiclass:: routingblocks.RemovalMove
    :members:
    :undoc-members:

.. autoapiclass:: routingblocks.RemovalCache
    :members:
    :undoc-members:

Miscellaneous
-------------

.. autoapiclass:: routingblocks.Random
    :members:
    :undoc-members:
